Learn R Programming

metasnf (version 2.1.2)

abcd_colour: Mock ABCD "colour" data

Description

A randomly shuffled and anonymized copy of depression data from the NIMH Data archive. The original file used was pdem02.txt. The file was pre-processed by the abcdutils package (https://github.com/BRANCHlab/abcdutils) function get_cbcl_depress. The data was transformed into categorical colour values to demonstrate the Chi-squared test capabilities of extend_solutions.

Usage

abcd_colour

Arguments

Format

abcd_colour

A data frame with 275 rows and 2 columns:

patient

The unique identifier of the ABCD dataset

colour

Categorical transformation of cbcl_depress.