Learn R Programming

metasnf (version 2.1.2)

abcd_pubertal: Mock ABCD pubertal status data

Description

A randomly shuffled and anonymized copy of pubertal status data from the NIMH Data archive. The original files used were abcd_ssphp01.txt and abcd_ssphy01.txt. The file was pre-processed by the abcdutils package (https://github.com/BRANCHlab/abcdutils) function get_pubertal_status.

Usage

abcd_pubertal

Arguments

Format

abcd_pubertal

A data frame with 275 rows and 2 columns:

patient

The unique identifier of the ABCD dataset

pubertal_status

Average reported pubertal status between child and parent (1-5 categorical scale)