Learn R Programming

metasnf (version 2.1.2)

as.data.frame.data_list: Coerce a data_list class object into a data.frame class object

Description

Horizontally joins data frames within a data list into a single data frame, using the uid attribute as the joining key.

Usage

# S3 method for data_list
as.data.frame(x, row.names = NULL, optional = FALSE, ...)

Value

dl_df A data.frame class object with all the features and observations of dl.

Arguments

x

A data_list class object.

row.names

Additional parameter passed to as.data.frame().

optional

Additional parameter passed to as.data.frame().

...

Additional parameter passed to as.data.frame().