solutions_df class object into a data.frame class objectCoerce a solutions_df class object into a data.frame class object
# S3 method for solutions_df
as.data.frame(
x,
row.names = NULL,
optional = FALSE,
keep_attributes = FALSE,
...
)A data.frame class object with all the columns of x and its
contained solutions data frame.
A solutions_df class object.
Additional parameter passed to as.data.frame().
Additional parameter passed to as.data.frame().
If TRUE, resulting data frame includes settings data frame and weights matrix.
Additional parameter passed to as.data.frame().