Learn R Programming

metasnf (version 2.1.2)

cat_colours: Helper function for generating categorical colour palette

Description

Helper function for generating categorical colour palette

Usage

cat_colours(vector, palette)

Value

A named list of colours where the names correspond to the unique values of vector and the values correspond to their colours.

Arguments

vector

Vector of categorical data to generate palette for.

palette

Which RColorBrewer palette should be used.