Learn R Programming

metasnf (version 2.1.2)

check_dataless_annotations: Helper function to stop annotation building when no data was provided

Description

Helper function to stop annotation building when no data was provided

Usage

check_dataless_annotations(annotation_requests, data)

Value

Does not return any value. This function just raises an error when annotations are requested without any provided data for a heatmap.

Arguments

annotation_requests

A list of requested annotations

data

A data frame with data to build annotations