Learn R Programming

metasnf (version 2.1.2)

check_dll_subitem_classes: Check if UID columns in a nested list have valid structure for a data list

Description

Check if UID columns in a nested list have valid structure for a data list

Usage

check_dll_subitem_classes(dll)

Value

Raises an error if the UID columns do not have a valid structure.

Arguments

dll

A data list-like list class object.