Learn R Programming

metasnf (version 2.1.2)

check_valid_k: Check if max K exceeds the number of observations

Description

Check if max K exceeds the number of observations

Usage

check_valid_k(sdf, dl)

Value

Doesn't return any value. Raises error if max K exceeds the number of observations.

Arguments

sdf

A settings_df class object.

dl

A nested list of input data from data_list().