Given a numeric vector and min and max colour values, return a colour ramp
that assigns a colour to each element in the vector. This function is a
wrapper for circlize::colorRamp2.'
colour_scale(data, min_colour, max_colour)A "function" class object that can build a circlize-style colour ramp.
Vector of numeric values.
Minimum colour value.
Maximum colour value.