Learn R Programming

metasnf (version 2.1.2)

convert_uids: Convert unique identifiers of data list to "uid"

Description

Column name "uid" is reserved for the unique identifier of observations. This function ensures all data frames have their UID set as "uid".

Usage

convert_uids(dll, uid)

Value

The provided nested list with "uid" as UID.

Arguments

dll

A data list-like list class object.

uid

(string) the name of the uid column currently used data