powered by
Defunct function to summarize a data list. Please use summary() with argument scope = "feature" instead.
summary()
scope = "feature"
dl_variable_summary(dl)
variable_level_summary A data frame containing the name, type, and domain of every variable in a data list.
A nested list of input data from data_list().
data_list()