dplyr_row_slice.solutions_df: Function to extend dplyr to solutions data frame objects

View source: R/dplyr.R

dplyr_row_slice.solutions_dfR Documentation

Function to extend dplyr to solutions data frame objects

Description

Function to extend dplyr to solutions data frame objects

Usage

dplyr_row_slice.solutions_df(data, i, ...)

Arguments

data

A solutions data frame.

i

A vector of row indices.

...

Additional arguments.

Value

Row sliced object with appropriately preserved attributes.


metasnf documentation built on June 20, 2026, 1:06 a.m.