Learn R Programming

metasnf (version 2.1.2)

ensure_dll_df: Ensure the data item of each component is a data.frame class object

Description

Ensure the data item of each component is a data.frame class object

Usage

ensure_dll_df(dll)

Value

The provided dll with the data item of each component as a data frame.

Arguments

dll

A data list-like list class object.