Intermediate function that takes in formatted lists of features and the annotations they should be viewed through and returns annotation objects usable by ComplexHeatmap::Heatmap.
generate_annotations_list(
df,
left_bar = NULL,
right_bar = NULL,
top_bar = NULL,
bottom_bar = NULL,
left_hm = NULL,
right_hm = NULL,
top_hm = NULL,
bottom_hm = NULL,
show_legend = TRUE,
annotation_colours = NULL
)annotations_list A named list of all the annotations.
data frame containing all the data that is specified in the remaining arguments.
Named list of strings, where the strings are features in df that should be used for a barplot annotation on the left of the plot and the names are the names that will be used to caption the plots and their legends.
See left_bar.
See left_bar.
See left_bar.
Like left_bar, but with a heatmap annotation instead of a barplot annotation.
See left_hm.
See left_hm.
See left_hm.
Add legends to the annotations.
Named list of heatmap annotations and their colours.