Deprecated function for building extracting cluster solutions from a
solutions data frame. Please use
t() instead.
This function takes in a single row of a solutions data frame and returns a
data frame containing the cluster assignments for each uid. It is
similar to get_clusters(), which takes one solutions data frame row and
returns a vector of cluster assignments' and get_cluster_solutions(),
which takes a solutions data frame with any number of rows and returns a
data frame indicating the cluster assignments for each of those rows.
get_cluster_df(sol_df_row)cluster_df data frame of cluster and uid.
One row from a solutions data frame.