Deprecated function for building extracting cluster solutions from a
solutions data frame. Please use
t() instead.
This function takes in a solutions data frame and returns a data frame containing
the cluster assignments for each uid. It is similar to
'get_clusters(), which takes one solutions data frame row and returns a vector
of cluster assignments' and get_cluster_df(), which takes a solutions
matrix with only one row and returns a data frame with two columns: "cluster"
and "uid" (the UID of the observation).
get_cluster_solutions(sol_df)A "data.frame" object where each row is an observation and each column (apart from the uid column) indicates the cluster that observation as assigned to for the corresponding solutions data frame row.
A sol_df.