Learn R Programming

metasnf (version 2.1.2)

get_heatmap_order: Return the row or column ordering present in a heatmap

Description

Return the row or column ordering present in a heatmap

Usage

get_heatmap_order(heatmap, type = "rows")

Value

A numeric vector of the ordering used within the provided ComplexHeatmap "Heatmap" object.

Arguments

heatmap

A heatmap object to collect ordering from.

type

The type of ordering to return. Either "rows" or "columns".