gexclude: Helper function to drop columns from a data frame by grepl...

View source: R/utils.R

gexcludeR Documentation

Helper function to drop columns from a data frame by grepl search

Description

Helper function to drop columns from a data frame by grepl search

Usage

gexclude(x, pattern)

Arguments

x

Data frame to drop columns from.

pattern

Pattern used to match columns to drop.

Value

x without columns matching pattern.


metasnf documentation built on June 20, 2026, 1:06 a.m.