gselect: Helper function to pick columns from a data frame by 'grepl'...

View source: R/utils.R

gselectR Documentation

Helper function to pick columns from a data frame by grepl search

Description

Helper function to pick columns from a data frame by grepl search

Usage

gselect(x, pattern)

Arguments

x

Data frame to select columns from.

pattern

Pattern used to match columns to select.

Value

x with only columns matching pattern.


metasnf documentation built on June 20, 2026, 1:06 a.m.