Learn R Programming

metasnf (version 2.1.2)

merge.data_list: Merge observations between two compatible data lists

Description

Join two data lists with the same components (data frames) but separate observations. To instead merge two data lists that have the same observations but different components, simply use c().

Usage

# S3 method for data_list
merge(x, y, ...)

Value

A data list ("list"-class object) containing the observations of both provided data lists.

Arguments

x

The first data list to merge.

y

The second data list to merge.

...

Additional arguments passed into merge function.