Learn R Programming

metasnf (version 2.1.2)

pick_cols: Helper function to pick columns from a data frame

Description

Helper function to pick columns from a data frame

Usage

pick_cols(x, cols)

Value

x with only columns in cols

Arguments

x

A data frame

cols

Vector of column names to be picked