This plot, built on ComplexHeatmap::Heatmap(), visualizes the cluster
assignments in a solutions data frame as a categorical heatmap with
observations along the columns and clusters along the rows.
# S3 method for solutions_df
plot(
x,
y = NULL,
cluster_rows = FALSE,
cluster_columns = TRUE,
heatmap_legend_param = NULL,
row_title = "Solution",
column_title = "Observation",
...
)# S3 method for t_solutions_df
plot(x, ...)
A ComplexHeatmap::Heatmap() object visualization of cluster
assignments.
A solutions_df object.
Optional argument to plot, not used in this method.
If the value is a logical, it controls whether to make cluster on rows. The value can also be a hclust or a dendrogram which already contains clustering. Check https://jokergoo.github.io/ComplexHeatmap-reference/book/a-single-heatmap.html#clustering .
Whether make cluster on columns? Same settings as cluster_rows.
A list contains parameters for the heatmap legends. See color_mapping_legend,ColorMapping-method for all available parameters.
Title on the row.
Title on the column.
Additional arguments passed to ComplexHeatmap::Heatmap().