Learn R Programming

metasnf (version 2.1.2)

print.ari_matrix: Print method for class ari_matrix

Description

Custom formatted print for weights matrices that outputs information about feature weights functions to the console.

Usage

# S3 method for ari_matrix
print(x, ...)

Value

Function prints to console but does not return any value.

Arguments

x

A ari_matrix class object.

...

Other arguments passed to print (not used in this function)