Learn R Programming

metasnf (version 2.1.2)

print.dist_fns_list: Print method for class dist_fns_list

Description

Custom formatted print for distance metrics list objects that outputs information about the contained distance metrics to the console.

Usage

# S3 method for dist_fns_list
print(x, ...)

Value

Function prints to console but does not return any value.

Arguments

x

A dist_fns_list class object.

...

Other arguments passed to print (not used in this function)