Learn R Programming

metasnf (version 2.1.2)

print.solutions_df: Print method for class solutions_df

Description

Custom formatted print for weights matrices that outputs information about feature weights functions to the console.

Usage

# S3 method for solutions_df
print(x, n = NULL, tips = TRUE, ...)

Value

Function prints to console but does not return any value.

Arguments

x

A weights_matrix class object.

n

Number of rows to print, passed into tibble::print.tbl_df().

tips

If TRUE, include lines on how to print more rows / transposed.

...

Other arguments passed to print (not used in this function).