remove_dll_incomplete: Remove observations with incomplete data from a data list-like list object
Description
Helper function during data_list class initialization. First applies
stats::na.omit() to the data frames named "data" within a nested list.
Then removes any observations that are not present across all data frames.
Usage
remove_dll_incomplete(dll)
Value
The provided dll with missing observations removed.
Arguments
- dll
A data list-like list class object.