reorder_dl_uids: Reorder the uids in a data list
Description
Reorder the uids in a data list
Usage
reorder_dl_uids(dl, ordered_uids)
Value
A data list ("list"-class object) with reordered observations.
Arguments
- dl
A nested list of input data from data_list().
- ordered_uids
A vector of the uid values in the data list
in the desired order of the sorted data list.