Helper function for running a single SNF config pipeline.
Arguments
- i
Row of settings_df and weights_matrix within SNF config to use.
- dl
A nested list of input data from
data_list().- sc
An
snf_configclass object which stores all sets of hyperparameters used to transform data in dl into a cluster solutions. See?settings_dfor https://branchlab.github.io/metasnf/articles/settings_df.html for more details.- return_sim_mats
If TRUE, function will return a list where the first element is the solutions data frame and the second element is a list of similarity matrices for each row in the sol_df. Default FALSE.
- sim_mats_dir
If specified, this directory will be used to save all generated similarity matrices.