Learn R Programming

metasnf (version 2.1.2)

solutions_df: Constructor for solutions_df class object

Description

Constructor for solutions_df class object

Usage

solutions_df(sol_dfl, smll, sc, dl)

Value

A solutions data frame (solutions_df class object).

Arguments

sol_dfl

A solutions data frame-like object to be validated and converted into a solutions data frame.

smll

A similarity matrix list-like object to be validated and used to construct a solutions data frame.

sc

An snf_config object used to construct a solutions data frame.

dl

An data_list object used to construct a solutions data frame.