Learn R Programming

metasnf (version 2.1.2)

summary.ari_matrix: Summary method for class ari_matrix

Description

Provides a summary of the ari_matrix class object, including the distribution of the adjusted Rand index (ARI) values and the number of solutions.

Usage

# S3 method for ari_matrix
summary(object, ...)

Value

A named list containing the number of solutions and the distribution of ARI values.

Arguments

object

A ari_matrix class object.

...

Other arguments passed to summary (not used in this function).