Learn R Programming

metasnf (version 2.1.2)

summary.settings_df: Summary method for class settings_df

Description

This summary function provides a summary of the settings_df class object, including the number of settings, the distribution of alpha values, the distribution of k values, and the distribution of clustering functions.

Usage

# S3 method for settings_df
summary(object, ...)

Value

A named list containing summary information of the settings data frame.

Arguments

object

A settings_df class object.

...

Other arguments passed to summary (not used in this function).