Learn R Programming

metasnf (version 2.1.2)

summary.snf_config: Summary method for class snf_config

Description

This summary function provides a summary of the snf_config class object, including the settings data frame, clustering functions list, distance functions list, and weights matrix.

Usage

# S3 method for snf_config
summary(object, ...)

Value

A named list containing the summaries of objects within the config.

Arguments

object

A snf_config class object.

...

Other arguments passed to summary (not used in this function).