solutions_dfThis summary function provides a summary of the solutions_df class
object, including the number of solutions, the distribution of the number of
clusters, and the number of observations.
# S3 method for solutions_df
summary(object, ...)A named list containing the number of solutions, the distribution of the number of clusters, and the number of observations.
A ext_solutions_df class object.
Other arguments passed to summary (not used in this function).