t_ext_solutions_dfThis summary function provides a summary of the t_ext_solutions_df class
object, including the number of solutions, the distribution of the number of
clusters, the number of features, the number of observations, and the
distribution of p-values.
# S3 method for t_ext_solutions_df
summary(object, ...)A named list containing the number of solutions, the distribution of the number of clusters, the number of features, the number of observations, and the distribution of p-values.
A t_ext_solutions_df class object.
Other arguments passed to summary (not used in this function).