Learn R Programming

metasnf (version 2.1.2)

summary.t_solutions_df: Summary method for class t_solutions_df

Description

This summary function provides a summary of the t_solutions_df class object, including the number of solutions, the distribution of the number of clusters, the number of features, the number of observations, and the distribution of p-values.

Usage

# S3 method for t_solutions_df
summary(object, ...)

Value

A named list containing the number of solutions, the distribution of the number of clusters, the number of features, the number of observations, and the distribution of p-values.

Arguments

object

A t_solutions_df class object.

...

Other arguments passed to summary (not used in this function).