Learn R Programming

metasnf (version 2.1.2)

summary.weights_matrix: Summary method for class weights_matrix

Description

This summary function provides a summary of the weights_matrix class object, including the minimum, maximum, mean, and standard deviation of the feature weights.

Usage

# S3 method for weights_matrix
summary(object, ...)

Value

A named list containing the summary statistics of the weights matrix, the number of solutions, and the number of features.

Arguments

object

A weights_matrix class object.

...

Other arguments passed to summary (not used in this function).