A randomly shuffled and anonymized copy of depression data from the NIMH
Data archive. The original file used was pdem02.txt. The file was
pre-processed by the abcdutils package
(https://github.com/BRANCHlab/abcdutils) function get_cbcl_depress.
The data was transformed into categorical colour values to demonstrate
the Chi-squared test capabilities of extend_solutions.
abcd_colourabcd_colour
A data frame with 275 rows and 2 columns:
The unique identifier of the ABCD dataset
Categorical transformation of cbcl_depress.