A randomly shuffled and anonymized copy of pubertal status data from the NIMH Data
archive. The original files used were abcd_ssphp01.txt and abcd_ssphy01.txt. The file was pre-processed
by the abcdutils package (https://github.com/BRANCHlab/abcdutils) function
get_pubertal_status.
abcd_pubertalabcd_pubertal
A data frame with 275 rows and 2 columns:
The unique identifier of the ABCD dataset
Average reported pubertal status between child and parent (1-5 categorical scale)