Defunct function to create an ARI heatmap. Please use
meta_cluster_heatmap() instead.
adjusted_rand_index_heatmap(
aris,
order = NULL,
cluster_rows = FALSE,
cluster_columns = FALSE,
log_graph = FALSE,
scale_diag = "none",
min_colour = "#282828",
max_colour = "firebrick2",
col = circlize::colorRamp2(c(min(aris), max(aris)), c(min_colour, max_colour)),
...
)Returns a heatmap (class "Heatmap" from package ComplexHeatmap) that displays the pairwise adjusted Rand indices (similarities) between the cluster solutions of the provided solutions data frame.
Matrix of adjusted rand indices from calc_aris()
Numeric vector containing row order of the heatmap.
Whether rows should be clustered.
Whether columns should be clustered.
If TRUE, log transforms the graph.
Method of rescaling matrix diagonals. Can be "none" (don't change diagonals), "mean" (replace diagonals with average value of off-diagonals), or "zero" (replace diagonals with 0).
Colour used for the lowest value in the heatmap.
Colour used for the highest value in the heatmap.
Colour ramp to use for the heatmap.
Additional parameters passed to similarity_matrix_heatmap(),
the function that this function wraps.