Given a single row of a solutions data frame and data provided through a data list, this function will return a series of bar and/or jitter plots based on feature types.
auto_plot(
sol_df_row = NULL,
dl = NULL,
cluster_df = NULL,
return_plots = TRUE,
save = NULL,
jitter_width = 6,
jitter_height = 6,
bar_width = 6,
bar_height = 6,
verbose = FALSE
)By default, returns a list of plots (class "gg", "ggplot") with
one plot for every feature in the provided data list and/or target list.
If return_plots is FALSE, will instead return a single "data.frame"
object containing every provided feature for every observation in long
format.
A single row of a solutions data frame.
A data list containing data to plot.
Directly provide a cluster_df rather than a solutions matrix. Useful if plotting data from label propagated results.
If TRUE, the function will return a list of plots.
If FALSE, the function will instead return the full data frame used for
plotting.
If a string is provided, plots will be saved and this string will be used to prefix plot names.
Width of jitter plots if save is specified.
Height of jitter plots if save is specified.
Width of bar plots if save is specified.
Height of bar plots if save is specified.
If TRUE, output progress to console.