Calculate p-values based on feature vectors and their types
calc_assoc_pval(var1, var2, type1, type2, cat_test = "chi_squared")pval A p-value from a statistical test based on the provided types. Currently, this will either be the F-test p-value from a linear model if at least one feature is non-categorical, or the chi-squared test p-value if both features are categorical.
A single vector containing a feature.
A single vector containing a feature.
The type of var1 (continuous, discrete, ordinal, categorical).
The type of var2 (continuous, discrete, ordinal, categorical).
String indicating which statistical test will be used to associate cluster with a categorical feature. Options are "chi_squared" for the Chi-squared test and "fisher_exact" for Fisher's exact test.