cell_significance_fn: Place significance stars on ComplexHeatmap cells
Description
This is an internal function meant to be used to by the
assoc_pval_heatmap function.
Usage
cell_significance_fn(data)
Value
cell_fn Another function that is well-formatted for usage as the
cell_fun argument in ComplexHeatmap::Heatmap.
Arguments
- data
The matrix containing the cells to base the significance stars
on.