Helper function to stop annotation building when no data was provided
check_dataless_annotations(annotation_requests, data)Does not return any value. This function just raises an error when annotations are requested without any provided data for a heatmap.
A list of requested annotations
A data frame with data to build annotations