powered by
Column name "uid" is reserved for the unique identifier of observations. This function ensures all data frames have their UID set as "uid".
convert_uids(dll, uid)
The provided nested list with "uid" as UID.
A data list-like list class object.
list
(string) the name of the uid column currently used data