dplyr_row_slice.solutions_df: Function to extend dplyr to solutions data frame objects
Description
Function to extend dplyr to solutions data frame objects
Usage
dplyr_row_slice.solutions_df(data, i, ...)
Value
Row sliced object with appropriately preserved attributes.
Arguments
- data
A solutions data frame.
- i
A vector of row indices.
- ...
Additional arguments.