powered by
data.frame
Ensure the data item of each component is a data.frame class object
ensure_dll_df(dll)
The provided dll with the data item of each component as a data frame.
A data list-like list class object.
list