powered by
Manhattan plot of feature-cluster association p-values
esm_manhattan_plot( esm, neg_log_pval_thresh = 5, threshold = NULL, point_size = 5, jitter_width = 0.1, jitter_height = 0.1, text_size = 15, plot_title = NULL, hide_x_labels = FALSE, bonferroni_line = FALSE )
A Manhattan plot (class "gg", "ggplot") showing the association p-values of features against each solution in the provided solutions data frame.
Extended solutions data frame storing associations between features and cluster assignments. See ?extend_solutions.
?extend_solutions
Threshold for negative log p-values.
P-value threshold to plot dashed line at.
Size of points in the plot.
Width of jitter.
Height of jitter.
Size of text in the plot.
Title of the plot.
If TRUE, hides x-axis labels.
If TRUE, plots a dashed black line at the Bonferroni-corrected equivalent of the p-value threshold.
esm_manhattan_plot(mock_ext_solutions_df)
Run the code above in your browser using DataLab