Deprecated function for building a clustering algorithms list. Please use
clust_fns_list() (or better yet, snf_config()) instead.
generate_clust_algs_list(..., disable_base = FALSE)A list of clustering algorithm functions that can be passed into the batch_snf and generate_settings_list functions.
An arbitrary number of named clustering functions
If TRUE, do not prepend the base clustering algorithms (spectral_eigen and spectral_rot, which apply spectral clustering and use the eigen-gap and rotation cost heuristics respectively for determining the number of clusters in the graph.