Filter data to training or testing subjects only
keep_split.RdGiven a dataframe and the results of train_test_split(), return just the
data for subjects that were assigned the specified split.
Arguments
- df
Dataframe to be subsetted into training or testing split
- assigned_df
Dataframe containing "subjectkey" and "split" cols from
train_test_assign()- split
String indicating which split to keep ("train" or "test")
- uid
(string) the name of the uid column currently used data