Join two data lists with the same components (data frames) but separate
observations. To instead merge two data lists that have the same
observations but different components, simply use c().
# S3 method for data_list
merge(x, y, ...)A data list ("list"-class object) containing the observations of both provided data lists.
The first data list to merge.
The second data list to merge.
Additional arguments passed into merge function.