Learn R Programming

metasnf (version 2.1.2)

merge_df_list: Merge list of data frames into a single data frame

Description

This helper function combines all data frames in a single-level list into a single data frame.

Usage

merge_df_list(df_list, join = "inner", uid = "uid", no_na = FALSE)

Value

Inner join of all data frames in list.

Arguments

df_list

list of data frames.

join

String indicating if join should be "inner" or "full".

uid

Column name to join on. Default is "uid".

no_na

Whether to remove NA values from the merged data frame.

Examples

Run this code
merge_df_list(list(income, pubertal), uid = "unique_id")

Run the code above in your browser using DataLab