Parallel processing form of batch_snf
parallel_batch_snf(
dl,
dfl,
cfl,
sdf,
wm,
similarity_matrix_dir,
return_sim_mats,
processes
)The same values as ?batch_snf().
A data list.
An optional nested list containing which distance metric function should be used for the various feature types (continuous, discrete, ordinal, categorical, and mixed). See ?dist_fns_list for details on how to build this.
List of custom clustering algorithms to apply to the final fused network. See ?clust_fns_list.
matrix indicating parameters to iterate SNF through.
A matrix containing feature weights to use during distance matrix calculation. See ?weights_matrix for details on how to build this.
If specified, this directory will be used to save all generated similarity matrices.
If TRUE, function will return a list where the first element is the solutions data frame and the second element is a list of similarity matrices for each row in the sol_df. Default FALSE.
Number of parallel processes used when executing SNF.