This plot, built on ComplexHeatmap::Heatmap(), visualizes the feature
values in a data list as a continuous heatmap with observations along the
columns and features along the rows.
# S3 method for data_list
plot(
x,
y = NULL,
cluster_rows = TRUE,
cluster_columns = TRUE,
heatmap_legend_param = NULL,
row_title = "Observation",
column_title = "Feature",
show_row_names = FALSE,
...
)A heatmap visualization of feature values.
A data_list object.
Optional argument to plot, not used in this method.
Logical indicating whether to cluster the rows (observations).
Logical indicating whether to cluster the columns (features).
A list of parameters for the heatmap legend.
Title for the rows (observations).
Title for the columns (features).
Logical indicating whether to show row names.
Additional arguments passed to ComplexHeatmap::Heatmap().