print.clust_fns_list: Print method for class clust_fns_list
Description
Custom formatted print for clustering functions list objects that outputs
information about the contained clustering functions to the console.
Usage
# S3 method for clust_fns_list
print(x, ...)
Value
Function prints to console but does not return any value.
Arguments
- x
A clust_fns_list class object.
- ...
Other arguments passed to print (not used in this function)