print.data_list: Print method for class data_list
Description
Custom formatted print for data list objects that outputs information about
the contained observations and components to the console.
Usage
# S3 method for data_list
print(x, ...)
Value
Function prints to console but does not return any value.
Arguments
- x
A data_list class object.
- ...
Other arguments passed to print (not used in this function)