print.settings_df: Print method for class settings_df
Description
Custom formatted print for settings data frame that outputs information
about SNF hyperparameters to the console.
Usage
# S3 method for settings_df
print(x, ...)
Value
Function prints to console but does not return any value.
Arguments
- x
A settings_df class object.
- ...
Other arguments passed to print (not used in this function)