solutions_dfCustom formatted print for weights matrices that outputs information about feature weights functions to the console.
# S3 method for solutions_df
print(x, n = NULL, tips = TRUE, ...)Function prints to console but does not return any value.
A weights_matrix class object.
Number of rows to print, passed into tibble::print.tbl_df().
If TRUE, include lines on how to print more rows / transposed.
Other arguments passed to print (not used in this function).