print.t_ext_solutions_df: Print method for class t_ext_solutions_df
Description
Custom formatted print for transposed solutions data frame class objects.
Usage
# S3 method for t_ext_solutions_df
print(x, ...)
Value
Function prints to console but does not return any value.
Arguments
- x
A t_solutions_df class object.
- ...
Other arguments passed to print (not used in this function)