Helper function for running a single SNF config pipeline.
run_snf(i, dl, sc, return_sim_mats, sim_mats_dir, p)A list containing a cluster solution (numeric vector) and a the fused network used to create that cluster solution. The fused network is NULL if return_sim_mats is FALSE.
Row of settings_df and weights_matrix within SNF config to use.
A nested list of input data from data_list().
An snf_config class object which stores all sets of
hyperparameters used to transform data in dl into a cluster solutions. See
?settings_df or
https://branchlab.github.io/metasnf/articles/settings_df.html for more
details.
If TRUE, function will return a list where the first element is the solutions data frame and the second element is a list of similarity matrices for each row in the sol_df. Default FALSE.
If specified, this directory will be used to save all generated similarity matrices.