siw_euclidean_distance: Squared (including weights) Euclidean distance
Description
Squared (including weights) Euclidean distance
Usage
siw_euclidean_distance(df, weights_row)
Value
distance_matrix A distance matrix.
Arguments
- df
data frame containing at least 1 data column.
- weights_row
Single-row data frame where the column names contain the
column names in df and the row contains the corresponding weights.