- dl
A nested list of input data from data_list().
- sdf
A settings_df class object. Overrides settings data frame
related parameters.
- dfl
A dist_fns_list class object. Overrides distance functions list
related parameters.
- cfl
A clust_fns_list class object. Overrides clustering functions
list related parameters.
- wm
A weights_matrix class object. Overrides weights matrix
related parameters.
- n_solutions
Number of rows to generate for the settings data frame.
- min_removed_inputs
The smallest number of input data frames that may be
randomly removed. By default, 0.
- max_removed_inputs
The largest number of input data frames that may be
randomly removed. By default, this is 1 less than all the provided input
data frames in the data list.
- dropout_dist
Parameter controlling how the random removal of input
data frames should occur. Can be "none" (no input data frames are randomly
removed), "uniform" (uniformly sample between min_removed_inputs and
max_removed_inputs to determine number of input data frames to remove), or
"exponential" (pick number of input data frames to remove by sampling from
min_removed_inputs to max_removed_inputs with an exponential distribution;
the default).
- min_alpha
The minimum value that the alpha hyperparameter can have.
Random assigned value of alpha for each row will be obtained by uniformly
sampling numbers between min_alpha and max_alpha at intervals of 0.1.
Cannot be used in conjunction with the alpha_values parameter.
- max_alpha
The maximum value that the alpha hyperparameter can have.
See min_alpha parameter. Cannot be used in conjunction with the
alpha_values parameter.
- min_k
The minimum value that the k hyperparameter can have.
Random assigned value of k for each row will be obtained by uniformly
sampling numbers between min_k and max_k at intervals of 1.
Cannot be used in conjunction with the k_values parameter.
- max_k
The maximum value that the k hyperparameter can have.
See min_k parameter. Cannot be used in conjunction with the
k_values parameter.
- min_t
The minimum value that the t hyperparameter can have.
Random assigned value of t for each row will be obtained by uniformly
sampling numbers between min_t and max_t at intervals of 1.
Cannot be used in conjunction with the t_values parameter.
- max_t
The maximum value that the t hyperparameter can have.
See min_t parameter. Cannot be used in conjunction with the
t_values parameter.
- alpha_values
A number or numeric vector of a set of possible values
that alpha can take on. Value will be obtained by uniformly sampling the
vector. Cannot be used in conjunction with the min_alpha or max_alpha
parameters.
- k_values
A number or numeric vector of a set of possible values
that k can take on. Value will be obtained by uniformly sampling the
vector. Cannot be used in conjunction with the min_k or max_k
parameters.
- t_values
A number or numeric vector of a set of possible values
that t can take on. Value will be obtained by uniformly sampling the
vector. Cannot be used in conjunction with the min_t or max_t
parameters.
- possible_snf_schemes
A vector containing the possible snf_schemes to
uniformly randomly select from. By default, the vector contains all
3 possible schemes: c(1, 2, 3). 1 corresponds to the "individual" scheme,
2 corresponds to the "domain" scheme, and 3 corresponds to the "two-step"
scheme.
- clustering_algorithms
A list of clustering algorithms to uniformly
randomly pick from when clustering. When not specified, randomly select
between spectral clustering using the eigen-gap heuristic and spectral
clustering using the rotation cost heuristic. See ?clust_fns_list
for more details on running custom clustering algorithms.
- continuous_distances
A vector of continuous distance metrics to use
when a custom dist_fns_list is provided.
- discrete_distances
A vector of categorical distance metrics to use
when a custom dist_fns_list is provided.
- ordinal_distances
A vector of categorical distance metrics to use
when a custom dist_fns_list is provided.
- categorical_distances
A vector of categorical distance metrics to use
when a custom dist_fns_list is provided.
- mixed_distances
A vector of mixed distance metrics to use
when a custom dist_fns_list is provided.
- snf_input_weights
Nested list containing weights for when SNF is
used to merge individual input measures (see ?generate_snf_weights)
- snf_domain_weights
Nested list containing weights for when SNF is
used to merge domains (see ?generate_snf_weights)
- retry_limit
The maximum number of attempts to generate a novel row.
This function does not return matrices with identical rows. As the range of
requested possible settings tightens and the number of requested rows
increases, the risk of randomly generating a row that already exists
increases. If a new random row has matched an existing row retry_limit
number of times, the function will terminate.
- cnt_dist_fns
A named list of continuous distance metric functions.
- dsc_dist_fns
A named list of discrete distance metric functions.
- ord_dist_fns
A named list of ordinal distance metric functions.
- cat_dist_fns
A named list of categorical distance metric functions.
- mix_dist_fns
A named list of mixed distance metric functions.
- automatic_standard_normalize
If TRUE, will automatically use
standard normalization prior to calculation of any numeric distances. This
parameter overrides all other distance functions list-related parameters.
- use_default_dist_fns
If TRUE, prepend the base distance metrics
(euclidean distance for continuous, discrete, and ordinal data and gower
distance for categorical and mixed data) to the resulting distance metrics
list.
- clust_fns
A list of named clustering functions
- use_default_clust_fns
If TRUE, prepend the base clustering algorithms
(spectral_eigen and spectral_rot, which apply spectral clustering and use
the eigen-gap and rotation cost heuristics respectively for determining
the number of clusters in the graph) to clust_fns.
- weights_fill
String indicating what to populate generate rows with.
Can be "ones" (default; fill matrix with 1), "uniform" (fill matrix with
uniformly distributed random values), or "exponential" (fill matrix with
exponentially distributed random values).