solutions_df class objectConstructor for solutions_df class object
solutions_df(sol_dfl, smll, sc, dl)A solutions data frame (solutions_df class object).
A solutions data frame-like object to be validated and converted into a solutions data frame.
A similarity matrix list-like object to be validated and used to construct a solutions data frame.
An snf_config object used to construct a solutions data frame.
An data_list object used to construct a solutions data frame.