settings_dfThis summary function provides a summary of the settings_df class
object, including the number of settings, the distribution of alpha values,
the distribution of k values, and the distribution of clustering functions.
# S3 method for settings_df
summary(object, ...)A named list containing summary information of the settings data frame.
A settings_df class object.
Other arguments passed to summary (not used in this function).