snf_configThis summary function provides a summary of the snf_config class object,
including the settings data frame, clustering functions list, distance
functions list, and weights matrix.
# S3 method for snf_config
summary(object, ...)A named list containing the summaries of objects within the config.
A snf_config class object.
Other arguments passed to summary (not used in this function).