weights_matrixThis summary function provides a summary of the weights_matrix class
object, including the minimum, maximum, mean, and standard deviation of the
feature weights.
# S3 method for weights_matrix
summary(object, ...)A named list containing the summary statistics of the weights matrix, the number of solutions, and the number of features.
A weights_matrix class object.
Other arguments passed to summary (not used in this function).